.. _trojanvision.attacks:

attacks
========

.. currentmodule:: trojanvision.attacks


.. toctree::
   :maxdepth: 3

   adv
   backdoor/index


.. autofunction:: add_argument
.. autofunction:: create

.. autoclass:: BackdoorAttack
   :members:

.. autoclass:: CleanLabelBackdoor
   :members:

.. autoclass:: DynamicBackdoor
   :members:
